@@ -1,17 +1,17 @@
 package Music::Interval::Barycentric;
 our $AUTHORITY = 'cpan:GENE';
+
 # ABSTRACT: Compute barycentric musical interval space
 
 use strict;
 use warnings;
 
-our $VERSION = '0.0105';
+our $VERSION = '0.02';
 
 use List::Util qw( min );
-use Readonly;
 
-Readonly my $SIZE  => 3;  # Triad chord
-Readonly my $SCALE => 12; # Scale notes
+my $SIZE  = 3;  # Triad chord
+my $SCALE = 12; # Scale notes
 
 
 sub barycenter {
@@ -72,6 +72,8 @@ sub evenness_index {
     return $i;
 }
 
+1;
+
 __END__
 
 =pod
@@ -84,17 +86,17 @@ Music::Interval::Barycentric - Compute barycentric musical interval space
 
 =head1 VERSION
 
-version 0.0105
+version 0.02
 
 =head1 SYNOPSIS
 
  use Music::Interval::Barycentric;
- print join(', ', Music::Interval::Barycentric::barycenter(3)), "\n";
  my @chords = ([3, 4, 5], [0, 4, 7]);
- printf "D: %.3f\n", Music::Interval::Barycentric::distance($chords[0], $chords[1]);
- print Music::Interval::Barycentric::evenness_index($chords[0]);
- print Music::Interval::Barycentric::orbit_distance(@chords), "\n";
- print Music::Interval::Barycentric::forte_distance(@chords), "\n";
+ print 'Barycenter: ', join(', ', Music::Interval::Barycentric::barycenter(3)), "\n";
+ printf "Distance: %.3f\n", Music::Interval::Barycentric::distance($chords[0], $chords[1]);
+ print 'Evenness index: ', Music::Interval::Barycentric::evenness_index($chords[0]), "\n";
+ print 'Orbit distance: ', Music::Interval::Barycentric::orbit_distance(@chords), "\n";
+ print 'Forte distance: ', Music::Interval::Barycentric::forte_distance(@chords), "\n";
 
 =head1 DESCRIPTION
 
@@ -154,7 +156,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Gene Boggs.
+This software is copyright (c) 2018 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
